@@ -8,6 +8,7 @@ import os
 import sys
 import tempfile
 
+import commands
 from subprocess import Popen, PIPE
 from logger import LOG
 
@@ -34,6 +35,9 @@ def runcmd(cmd):
             status = os.system(cmd)
             return status, ''
 
+        elif execute_mode == 'commands':
+            return commands.getstatusoutput(cmd)
+
         elif execute_mode == 'process':
 
             stdin = open('/dev/null')
